@@ -21,6 +21,11 @@ class SynchronizeUsers(threading.Thread):
 		self.silent = silent
 		self.synchronize_interval = synchronize_interval
 		self.sleep_interval = sleep_interval
+		self.monthly_requests, self.monthly_costs = self.get_costs(self.synchronize_interval, len(self.restapi.uid_api_keys))
+		monthly_requests, costs = self.get_costs(self.synchronize_interval, 10000)
+		print(f"Monthly daemon requests: {int(self.monthly_requests)}")
+		print(f"Monthly daemon costs: € {self.monthly_costs:.2f}")
+		print(f"Monthly daemon costs per 10.000 users: € {monthly_costs:.2f}")
 	def run(self):
 		last = None
 		while True:
@@ -31,6 +36,10 @@ class SynchronizeUsers(threading.Thread):
 				new = date.compare(increased, date.timestamp) in ["present", "past"]
 			if new:
 				last = date.timestamp
-				response = self.restapi.users.synchronize(silent=self.silent)
+				response = self.restapi.synchronize_users(silent=self.silent)
 				r3sponse.log(response, log_level=-1, save_errors=True)
-			time.sleep(self.sleep_interval*60)
\ No newline at end of file
+			time.sleep(self.sleep_interval*60)
+	def get_costs(self, synchronize_interval=None, total_users=None):
+		monthly_requests = ( total_users * (( 60 * 24 ) / synchronize_interval )) * 30.5
+		monthly_costs = monthly_requests * (0.06/100000)
+		return monthly_requests, monthly_costs
\ No newline at end of file
