@@ -141,22 +141,23 @@ class RestAPI(object):
 					"plans":{},
 				}
 				#	-	subscription plan summary:
-				subscription_plans = subscription['items']['data']
-				for subscription_plan in subscription_plans:
-					id = subscription_plan['plan']['id']
-					try: subscriptions[email]["plans"][id]
-					except KeyError: subscriptions[email]["plans"][id] = {}
-					active = subscription_plan['plan']['active']
-					if active in [True, "true", "True", "TRUE"]: active = True
-					else: active = False
-					if not active_only or (active_only and active):
-						subscriptions[email]["plans"][id]["subscription_id"] = subscription_plan['id']
-						subscriptions[email]["plans"][id]["plan_id"] = subscription_plan['plan']['id']
-						subscriptions[email]["plans"][id]["plan_nickname"] = subscription_plan['plan']['nickname']
-						subscriptions[email]["plans"][id]["plan_active_status"] = active
+				status = subscription["status"]
+				if not active_only or (active_only and status != "canceled"): 
+					subscription_plans = subscription['items']['data']
+					for subscription_plan in subscription_plans:
+						id = subscription_plan['plan']['id']
+						try: subscriptions[email]["plans"][id]
+						except KeyError: subscriptions[email]["plans"][id] = {}
+						active = subscription_plan['plan']['active']
+						if active in [True, "true", "True", "TRUE"]: active = True
+						else: active = False
+						if not active_only or (active_only and active):
+							subscriptions[email]["plans"][id]["subscription_id"] = subscription_plan['subscription']
+							subscriptions[email]["plans"][id]["plan_id"] = subscription_plan['plan']['id']
+							subscriptions[email]["plans"][id]["plan_nickname"] = subscription_plan['plan']['nickname']
+							subscriptions[email]["plans"][id]["plan_active_status"] = active
 
 			# success.
-			print("SUBSCRIPTIONS:",json.dumps(subscriptions, indent=4))
 			return r3sponse.success_response("Successfully retrieved the subscriptions.", {
 				"subscriptions":subscriptions,
 			})
@@ -185,9 +186,6 @@ class RestAPI(object):
 				return r3sponse.error_response(f"Unable to find any subscriptions for user [{uid}].")	
 
 		# get subscription id.
-		print(plans)
-		print(self.__plans__[plan]["plan_id"])
-		print(plans[self.__plans__[plan]["plan_id"]])
 		try:
 			subscription_id = plans[self.__plans__[plan]["plan_id"]]["subscription_id"]
 		except KeyError:
@@ -196,14 +194,14 @@ class RestAPI(object):
 		# delete.
 		try:
 			r = self.stripe.Subscription.delete(subscription_id)
-			success = r["status"] = "canceled"
-		except KeyError: success = False
+			success = r["status"] == "canceled"
+		except Exception as e: success = str(e)
 
 		# handle success.
-		if success:
+		if success == True:
 			return r3sponse.success_response(f"Successfully canceled the subscription for user [{uid}] from plan [{plan}].")
 		else:
-			return r3sponse.error_response(f"Failed to cancel the subscription for user [{uid}] from plan [{plan}].")
+			return r3sponse.error_response(f"Failed to cancel the subscription for user [{uid}] from plan [{plan}], error: {success}.")
 
 		#
 	def get_customer_id(self, 
